package IO::K8s::Api::Autoscaling::V2::HorizontalPodAutoscalerStatus;
# ABSTRACT: HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler.
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s conditions => ['Autoscaling::V2::HorizontalPodAutoscalerCondition'];


k8s currentMetrics => ['Autoscaling::V2::MetricStatus'];


k8s currentReplicas => Int;


k8s desiredReplicas => Int, 'required';


k8s lastScaleTime => Str;


k8s observedGeneration => Int;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Autoscaling::V2::HorizontalPodAutoscalerStatus - HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler.

=head1 VERSION

version 1.000

=head2 conditions

conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met.

=head2 currentMetrics

currentMetrics is the last read state of the metrics used by this autoscaler.

=head2 currentReplicas

currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler.

=head2 desiredReplicas

desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler.

=head2 lastScaleTime

lastScaleTime is the last time the HorizontalPodAutoscaler scaled the number of pods, used by the autoscaler to control how often the number of pods is changed.

=head2 observedGeneration

observedGeneration is the most recent generation observed by this autoscaler.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
